DataProcessor
========================================================

.. toctree::
    :maxdepth: 1

    Base Class for DataProcessor <base>


Built-in DataProcessor
-----------------------------

.. toctree::
    :maxdepth: 3

    Built-in DataProcessors <processors/index>

Custom DataProcessor Relevant
-----------------------------

.. toctree::
    :maxdepth: 2

    Extension hookspec <extension>
    DataProcessorManager <manager>
